import random
from SantasList.Objects import Pair


class Pairs(list):
    _pairs = []

    def __init__(self, people):
        while len(people) > 0:
            a = self._pop_list(people)
            b = self._pop_list(people)

            self._pairs.append(Pair(a, b))

        list.__init__(self, self._pairs)

    def __str__(self):
        return '\n'.join(str(x) for x in self._pairs)

    @staticmethod
    def _pop_list(my_list):
        indices = list(range(0, len(my_list)))

        x = random.choice(indices)
        y = my_list[x]

        del indices[x]
        del my_list[x]

        return y



from SantasList.Objects import People
from SantasList.Objects import Pairs


class SantasList(object):
    def __init__(self, people):
        self._people = People(people)

    def people(self):
        return self._people

    def matches(self):
        return Pairs(self._people)



from SantasList.Objects import Person


class People(list):
    _people = []

    def __init__(self, people):
        self._people = [Person(x) for x in people]

        list.__init__(self, self._people)

    def __str__(self):
        return ','.join(str(x) for x in self._people)



from SantasList.SantasList import SantasList

__author__ = 'Jeffrey Hann'
__version__ = '0.0.5'

_theList = None


def load_people(people):
    global _theList
    _theList = SantasList(people)


def list_matches():
    global _theList
    return _theList.matches()



#!/usr/bin/env python

import os
import re

from setuptools import setup, find_packages


ROOT = os.path.dirname(__file__)
VERSION_RE = re.compile(r'''__version__ = ['"]([0-9.]+)['"]''')

def get_version():
    init = open(os.path.join(ROOT, 'SantasList', '__init__.py')).read()
    return VERSION_RE.search(init).group(1)


setup(name='Santaslist',
      version=get_version(),
      description='Helping santa',
      scripts=[],
      author='Jeff Hann',
      author_email='jeffhann@gmail.com',
      url='https://github.com/obihann/Santaslist',
      classifiers=[
          'Development Status :: 3 - Alpha',
          'License :: OSI Approved :: GNU General Public License v2 or later (GPLv2+)',
          'Programming Language :: Python :: 3 :: Only',
          'Natural Language :: English',
          'Topic :: Utilities',
      ],
      packages=find_packages(exclude=['tests*']),
      install_requires=['pyyaml']
      )
